==> Mapster-1.3.9.zip: Mapster/Locale/zhTW.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "zhTW")
if not L then return end

L["Accuracy"] = "精確度"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "調校在地圖上玩家箭頭的大小以便更容易被看見"
L["Alpha"] = "透明度"
L["Battlegrounds"] = "戰場"
L["BattleMap"] = "戰鬥地圖"
L["Blobs & Panels"] = "任務點和面板"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "調整世界地圖的大小.它可以讓你的世界地圖不再覆蓋整個螢幕."
L["Coordinates"] = "座標功能"
L["Cursor"] = "游標"
L["Debug"] = "除錯模式"
L["Disable Mouse"] = "停用滑鼠"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "停用主地圖的滑鼠互動, 如改變區域。"
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "在最小化模式停用主地圖的滑鼠互動, 如改變區域。"
L["Enable BattleMap"] = "啟用戰鬥地圖"
L["Enable Coordinates"] = "啟用座標"
L["Enable FogClear"] = "啟用地圖全亮"
L["Enable Group Icons"] = "啟用隊伍圖示"
L["Enable Instance Maps"] = "啟用副本地圖"
L["FogClear"] = "地圖全亮"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "地圖全亮會在你的SavedVariables收集新的數據,但可能在一個新的升級程序後會損壞(或過時的)數據.如果您在世界地圖上看到破損現象, 請重置數據."
L["Group Icons"] = "隊伍圖示"
L["Hide Border"] = "隱藏邊緣"
L["Hide Completely"] = "完全隱藏"
L["Hide Map Button"] = "隱藏地圖按鈕"
L["Hide Textures"] = "隱藏材質"
L["Hide the borders of the big map."] = "隱藏大地圖的邊緣"
L["Hide the borders of the minimized map."] = "隱藏最小化地圖的邊緣"
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "隱藏周圍戰鬥地圖的材質, 只留下地圖的必要部份."
L["Instance Maps"] = "副本地圖"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster讓你改變世界地圖的各種樣式. 通過擴展插件來新增地圖功能,並可以為每個角色設置不同的配置."
L["(Mini) Disable Mouse"] = "(迷小) 停用滑鼠"
L["(Mini) Hide Border"] = "(迷小) 隱藏邊緣"
L["Minimized Alpha"] = "最小化透明度"
L["Minimized Scale"] = "最小化比例"
L["Northrend Instances"] = "北裂境副本"
L["Northrend Raids"] = "北裂境團隊副本"
L["Note: You need to reload your UI after reseting the data!"] = "注意:您需要重新載入你的用戶介面後數據才會重置!"
L["Only WorldMap Blobs"] = "只顯示任務點"
L["Overlay Color"] = "覆蓋顏色"
L["Player"] = "玩家"
L["PlayerArrow Scale"] = "玩家箭頭比例"
L["POI Scale"] = "POI 比例"
L["Quest Objectives"] = "任務目標"
L["Reset FogClear Data"] = "重置地圖全亮數據"
L["Scale"] = "比例"
L["Scale of the big map."] = "大地圖的比例"
L["Scale of the minimized map."] = "最小化地圖的比例"
L["Scale of the POI Icons on the Map."] = "在地圖 POI 圖示的比例"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "戰鬥地圖模組可讓您變更戰鬥地圖的樣式, 消除不必要的材質或PVP目標."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "在世界地圖上加入你當前位置座標和滑鼠位置座標."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "地圖全亮,顯示你沒去過的區域."
L["The Group Icons module converts the player icons on the World Map and the Zone/Battlefield map to more meaningful icons, showing their class and (in raids) their sub-group."] = "在世界地圖和區域/戰場地圖上增加功能更強大的標記.它們可以詳細的顯示出職業以及隊伍"
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "副本地圖模組可以在副本外查看游戲提供的副本和戰場地圖"
L["The transparency of the big map."] = "大地圖的透明度"
L["The transparency of the minimized map."] = "最小化地圖的透明度"
L["Turn on debugging for the FogClear Module."] = "開啟地圖全亮的除錯模式."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "改變世界地圖的透明度, 使你在打開地圖的情況下繼續操作你的人物."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "那你的座標顯示的更精確.例如:如果你需要精確的位置座標,那麼請設置到2."

==> Mapster-1.4.3.zip: Mapster/Locale/zhTW.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "zhTW")
if not L then return end

L["(Mini) Disable Mouse"] = "(迷小) 停用滑鼠"
L["(Mini) Hide Border"] = "(迷小) 隱藏邊緣"
L["Accuracy"] = "精確度"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "調校在地圖上玩家箭頭的大小以便更容易被看見"
L["Alpha"] = "透明度"
L["BattleMap"] = "戰鬥地圖"
L["Battlegrounds"] = "戰場"
L["Blobs & Panels"] = "任務點和面板"
L["Burning Crusade Instances"] = "燃燒的遠征副本"
L["Burning Crusade Raids"] = "燃燒的遠征團隊"
L["Cataclysm Instances"] = "浩劫與重生副本"
L["Cataclysm Raids"] = "浩劫與重生團隊"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "調整世界地圖的大小.它可以讓你的世界地圖不再覆蓋整個螢幕."
L["Classic Instances"] = "經典副本"
L["Classic Raids"] = "經典團隊"
L["Coordinates"] = "座標功能"
L["Cursor"] = "游標"
L["Debug"] = "除錯模式"
L["Disable Mouse"] = "停用滑鼠"
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "在最小化模式停用主地圖的滑鼠互動, 如改變區域。"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "停用主地圖的滑鼠互動, 如改變區域。"
L["Enable BattleMap"] = "啟用戰鬥地圖"
L["Enable Coordinates"] = "啟用座標"
L["Enable FogClear"] = "啟用地圖全亮"
L["Enable Group Icons"] = "啟用隊伍圖示"
L["Enable Instance Maps"] = "啟用副本地圖"
L["FogClear"] = "地圖全亮"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "地圖全亮會在你的SavedVariables收集新的數據,但可能在一個新的升級程序後會損壞(或過時的)數據.如果您在世界地圖上看到破損現象, 請重置數據."
L["Group Icons"] = "隊伍圖示"
L["Hide Border"] = "隱藏邊緣"
L["Hide Completely"] = "完全隱藏"
L["Hide Map Button"] = "隱藏地圖按鈕"
L["Hide Textures"] = "隱藏材質"
L["Hide the borders of the big map."] = "隱藏大地圖的邊緣"
L["Hide the borders of the minimized map."] = "隱藏最小化地圖的邊緣"
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "隱藏周圍戰鬥地圖的材質, 只留下地圖的必要部份."
L["Instance Maps"] = "副本地圖"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster讓你改變世界地圖的各種樣式. 通過擴展插件來新增地圖功能,並可以為每個角色設置不同的配置."
L["Minimized Alpha"] = "最小化透明度"
L["Minimized Scale"] = "最小化比例"
L["Note: You need to reload your UI after reseting the data!"] = "注意:您需要重新載入你的用戶介面後數據才會重置!"
L["Only WorldMap Blobs"] = "只顯示任務點"
L["Overlay Color"] = "覆蓋顏色"
L["POI Scale"] = "POI 比例"
L["Player"] = "玩家"
L["PlayerArrow Scale"] = "玩家箭頭比例"
L["Quest Objectives"] = "任務目標"
L["Reset FogClear Data"] = "重置地圖全亮資料"
L["Scale"] = "比例"
L["Scale of the POI Icons on the Map."] = "在地圖 POI 圖示的比例"
L["Scale of the big map."] = "大地圖的比例"
L["Scale of the minimized map."] = "最小化地圖的比例"
L["Size on the Battle Map"] = "戰鬥地圖尺寸"
L["Size on the World Map"] = "世界地圖尺寸"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "戰鬥地圖模組可讓您變更戰鬥地圖的樣式, 消除不必要的材質或PVP目標."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "在世界地圖上加入你當前位置座標和滑鼠位置座標."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "地圖全亮,顯示你沒去過的區域."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "隊伍圖示模塊允許你更改團隊和隊伍在世界地圖上的圖示大小。"
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "副本地圖模組可以在副本外查看游戲提供的副本和戰場地圖"
L["The transparency of the big map."] = "大地圖的透明度"
L["The transparency of the minimized map."] = "最小化地圖的透明度"
L["Turn on debugging for the FogClear Module."] = "開啟地圖全亮的除錯模式."
L["Wrath Instances"] = "巫妖王之怒副本"
L["Wrath Raids"] = "巫妖王之怒團隊"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "改變世界地圖的透明度, 使你在打開地圖的情況下繼續操作你的人物."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "那你的座標顯示的更精確.例如:如果你需要精確的位置座標,那麼請設置到2."
